compute_throughput_latency

Function compute_throughput_latency 

pub fn compute_throughput_latency<'a, Client: 'a>(
    clients: &Cluster<'a, Client>,
    latencies: Stream<Duration, Cluster<'a, Client>, Unbounded, NoOrder>,
    interval_millis: u64,
    nondet_measurement_window: NonDet,
) -> BenchResult<Cluster<'a, Client>>
Computes the throughput and latency of transactions and outputs it every interval_millis. An output is produced even if there are no transactions.

Non-Determinism

This function uses non-deterministic wall-clock windows for measuring throughput.